@@ -133,12 +133,29 @@ class FacebookParsedItem(object):
 
         return True
 
+    def __repr__(self):
+        class_name = self.__class__.__name__
+
+        representation = '<' + class_name
+
+        for key in self.__slots__:
+            value = getattr(self, key)
+
+            if value is None:
+                continue
+
+            representation += ' %s=%s' % (key, value)
+
+        representation += '>'
+
+        return representation
+
 
 class FacebookUser(FacebookParsedItem):
     __slots__ = ('id', 'handle')
 
-    def __init__(self, user_id, handle=None):
-        self.id = user_id
+    def __init__(self, id, handle=None):
+        self.id = id
         self.handle = handle
 
     @property
@@ -148,17 +165,6 @@ class FacebookUser(FacebookParsedItem):
 
         return urljoin(BASE_FACEBOOK_URL, '/%s' % self.handle)
 
-    def __repr__(self):
-        class_name = self.__class__.__name__
-
-        return (
-            '<%(class_name)s id=%(id)s handle=%(handle)s>'
-        ) % {
-            'class_name': class_name,
-            'id': self.id,
-            'handle': self.handle
-        }
-
 
 class FacebookHandle(FacebookParsedItem):
     __slots__ = ('handle',)
@@ -170,25 +176,32 @@ class FacebookHandle(FacebookParsedItem):
     def url(self):
         return urljoin(BASE_FACEBOOK_URL, '/%s' % self.handle)
 
-    def __repr__(self):
-        class_name = self.__class__.__name__
 
-        return (
-            '<%(class_name)s handle=%(handle)s>'
-        ) % {
-            'class_name': class_name,
-            'handle': self.handle
-        }
+class FacebookGroup(FacebookParsedItem):
+    __slots__ = ('id', 'handle')
+
+    def __init__(self, id=None, handle=None):
+        self.id = id
+        self.handle = handle
+
+    @property
+    def url(self):
+        if self.handle is not None:
+            return urljoin(BASE_FACEBOOK_URL, 'groups/%s' % self.handle)
+
+        return urljoin(BASE_FACEBOOK_URL, 'groups/%s' % self.id)
 
 
 class FacebookPost(FacebookParsedItem):
-    __slots__ = ('id', 'parent_id', 'group_id', 'parent_handle')
+    __slots__ = ('id', 'parent_id', 'parent_handle', 'group_id', 'group_handle')
 
-    def __init__(self, post_id, parent_id=None, group_id=None, parent_handle=None):
+    def __init__(self, post_id, parent_id=None, parent_handle=None,
+                 group_id=None, group_handle=None):
         self.id = post_id
         self.parent_id = parent_id
-        self.group_id = group_id
         self.parent_handle = parent_handle
+        self.group_id = group_id
+        self.group_handle = group_handle
 
     @property
     def url(self):
@@ -201,6 +214,9 @@ class FacebookPost(FacebookParsedItem):
         if self.group_id is not None:
             return urljoin(BASE_FACEBOOK_URL, '/groups/%s/permalink/%s' % (self.group_id, self.id))
 
+        if self.group_handle is not None:
+            return urljoin(BASE_FACEBOOK_URL, '/groups/%s/permalink/%s' % (self.group_handle, self.id))
+
     @property
     def full_id(self):
         if self.parent_id is not None:
@@ -211,18 +227,62 @@ class FacebookPost(FacebookParsedItem):
 
         return None
 
-    def __repr__(self):
-        class_name = self.__class__.__name__
 
-        return (
-            '<%(class_name)s id=%(id)s parent_id=%(parent_id)s group_id=%(group_id)s parent_handle=%(parent_handle)s>'
-        ) % {
-            'class_name': class_name,
-            'id': self.id,
-            'group_id': self.group_id,
-            'parent_id': self.parent_id,
-            'parent_handle': self.parent_handle
-        }
+class FacebookVideo(FacebookParsedItem):
+    __slots__ = ('id', 'parent_id')
+
+    def __init__(self, video_id, parent_id=None):
+        self.id = video_id
+        self.parent_id = parent_id
+
+    @property
+    def url(self):
+        if self.parent_id is None:
+            return urljoin(BASE_FACEBOOK_URL, '/watch/?v=%s' % self.id)
+
+        return urljoin(BASE_FACEBOOK_URL, '/%s/videos/%s' % (self.parent_id, self.id))
+
+
+class FacebookPhoto(FacebookParsedItem):
+    __slots__ = ('id', 'group_id', 'parent_id', 'parent_handle', 'album_id')
+
+    def __init__(self, photo_id, group_id=None, parent_id=None, parent_handle=None,
+                 album_id=None):
+        self.id = photo_id
+        self.group_id = group_id
+        self.parent_id = parent_id
+        self.parent_handle = parent_handle
+        self.album_id = album_id
+
+    @property
+    def url(self):
+        if self.group_id:
+            return urljoin(
+                BASE_FACEBOOK_URL,
+                '/photo.php?fbid=%s&set=g.%s' % (self.id, self.group_id)
+            )
+
+        if self.parent_id:
+            return urljoin(
+                BASE_FACEBOOK_URL,
+                '/%s/a.%s/%s' % (
+                    self.parent_id,
+                    self.album_id,
+                    self.id
+                )
+            )
+
+        if self.parent_handle:
+            return urljoin(
+                BASE_FACEBOOK_URL,
+                '/%s/a.%s/%s' % (
+                    self.parent_handle,
+                    self.album_id,
+                    self.id
+                )
+            )
+
+        return urljoin(BASE_FACEBOOK_URL, '/photo.php?fbid=%s' % self.id)
 
 
 def parse_facebook_url(url, allow_relative_urls=False):
@@ -244,6 +304,63 @@ def parse_facebook_url(url, allow_relative_urls=False):
     if not splitted.path or splitted.path == '/':
         return None
 
+    # Videos
+    if '/watch' in splitted.path:
+        query = parse_qs(splitted.query)
+
+        if 'v' not in query:
+            return None
+
+        video_id = query['v'][0]
+
+        return FacebookVideo(video_id)
+
+    if '/videos/' in splitted.path:
+        parts = urlpathsplit(splitted.path)
+
+        return FacebookVideo(parts[2], parent_id=parts[0])
+
+    # Photos
+    if splitted.query and (splitted.path.endswith('/photo.php') or splitted.path.endswith('/photo')):
+        query = parse_qs(splitted.query)
+
+        if 'fbid' not in query:
+            return None
+
+        group_id = None
+        album_id = None
+
+        if 'set' in query:
+            sets = query['set']
+
+            group_id = next((s for s in sets if s.startswith('g.')), None)
+
+            if group_id:
+                group_id = group_id.split('g.', 1)[1]
+
+            album_id = next((s for s in sets if s.startswith('a.')), None)
+
+            if album_id:
+                album_id = album_id.split('a.', 1)[1]
+
+        return FacebookPhoto(
+            query['fbid'][0],
+            group_id=group_id,
+            album_id=album_id
+        )
+
+    if '/photos/' in splitted.path:
+        parts = urlpathsplit(splitted.path)
+
+        parent_id_or_handle = parts[0]
+        album_id = parts[2].replace('a.', '')
+        photo_id = parts[3]
+
+        if is_facebook_id(parent_id_or_handle):
+            return FacebookPhoto(photo_id, album_id=album_id, parent_id=parent_id_or_handle)
+
+        return FacebookPhoto(photo_id, album_id=album_id, parent_handle=parent_id_or_handle)
+
     # Obvious post path
     if '/posts/' in splitted.path:
         parts = urlpathsplit(splitted.path)
@@ -261,10 +378,19 @@ def parse_facebook_url(url, allow_relative_urls=False):
         return FacebookPost(query['story_fbid'][0], parent_id=query['id'][0])
 
     # Group permalink path
-    if '/groups/' in splitted.path and '/permalink/' in splitted.path:
+    if '/groups/' in splitted.path:
         parts = urlpathsplit(splitted.path)
 
-        return FacebookPost(parts[3], group_id=parts[1])
+        if '/permalink/' in splitted.path:
+            if is_facebook_id(parts[1]):
+                return FacebookPost(parts[3], group_id=parts[1])
+
+            return FacebookPost(parts[3], group_handle=parts[1])
+
+        if is_facebook_id(parts[1]):
+            return FacebookGroup(id=parts[1])
+
+        return FacebookGroup(handle=parts[1])
 
     # Profile path
     if splitted.path == '/profile.php':
@@ -286,3 +412,19 @@ def parse_facebook_url(url, allow_relative_urls=False):
             return FacebookHandle(parts[0])
 
     return None
+
+
+FACEBOOK_TYPES_HAVING_COMMENTS = (
+    FacebookPost,
+    FacebookPhoto,
+    FacebookVideo
+)
+
+
+def has_facebook_comments(url, allow_relative_urls=False):
+    if not is_facebook_url(url):
+        return False
+
+    result = parse_facebook_url(url, allow_relative_urls=allow_relative_urls)
+
+    return isinstance(result, FACEBOOK_TYPES_HAVING_COMMENTS)
